sidpy
=====

.. image:: https://github.com/pycroscopy/sidpy/workflows/build/badge.svg?branch=master
    :target: https://github.com/pycroscopy/sidpy/actions?query=workflow%3Abuild
    :alt: GiHub Actions

.. image:: https://img.shields.io/pypi/v/sidpy.svg
    :target: https://pypi.org/project/sidpy/
    :alt: PyPI
    
.. image:: https://img.shields.io/conda/vn/conda-forge/sidpy.svg
    :target: https://github.com/conda-forge/sidpy-feedstock
    :alt: conda-forge
   
.. image:: https://codecov.io/gh/pycroscopy/sidpy/branch/master/graph/badge.svg?token=BCFR4FR6AL
    :target: https://codecov.io/gh/pycroscopy/sidpy
    :alt: coverage

.. image:: https://img.shields.io/pypi/l/sidpy.svg
    :target: https://pypi.org/project/sidpy/
    :alt: License

.. image:: http://pepy.tech/badge/sidpy
    :target: http://pepy.tech/project/sidpy
    :alt: Downloads

.. image:: https://zenodo.org/badge/138171750.svg
   :target: https://zenodo.org/badge/latestdoi/138171750
   :alt: USID DOI

Python utilities for storing and visualizing Spectroscopic and Imaging Data (SID)

Please see our `website <https://pycroscopy.github.io/sidpy/index.html>`_ for more information.
